<?php
//avoid direct calls to this file where wp core files not present
if ( !function_exists( 'add_action' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

$new_bp_gtm_admin = new BP_GTM_ADMIN_PAGE();

class BP_GTM_ADMIN_PAGE {

	//constructor of class, PHP4 compatible construction for backward compatibility (until WP 3.1)
	function bp_gtm_admin_page() {
		add_filter( 'screen_layout_columns', array( &$this, 'on_screen_layout_columns' ), 10, 2 );
		add_action( 'admin_menu', array( &$this, 'on_admin_menu' ) );
	}

	function on_screen_layout_columns( $columns, $screen ) {
		if ( $screen == $this->pagehook ) {
			$columns[ $this->pagehook ] = 2;
		}
		return $columns;
	}
	function on_admin_menu() {
		$this->pagehook = add_submenu_page( 'bp-general-settings', __( 'GTM System', 'bp_gtm' ), __( 'GTM System', 'bp_gtm' ), 'manage_options', 'bp-gtm-admin', array( &$this, 'on_show_page' ) );
		add_action( 'load-'.$this->pagehook, array( &$this, 'on_load_page' ) );
	}
	//will be executed if wordpress core detects this page has to be rendered
	function on_load_page() {
		wp_enqueue_script( 'common' );
		wp_enqueue_script( 'wp-lists' );
		wp_enqueue_script( 'postbox' );

		// sidebar
		add_meta_box( 'bp-gtm-admin-privacy', __( 'Dev print_var(bp_gtm)', 'bp_gtm' ), array(&$this, 'on_bp_gtm_admin_privacy'), $this->pagehook, 'side', 'core' );
		add_meta_box('bp-gtm-admin-mce', __( 'Rich Editor (TinyMCE)', 'bp_gtm' ), array(&$this, 'on_bp_gtm_admin_mce'), $this->pagehook, 'side', 'core');
		// main content - normal
		add_meta_box( 'bp-gtm-admin-main', __( 'Groups Selection', 'bp_gtm' ), array( &$this, 'on_bp_gtm_admin_main' ), $this->pagehook, 'normal', 'core' );
		add_meta_box('bp-gtm-admin-b-color', __( 'Deactivation Options', 'bp_gtm' ), array(&$this, 'on_bp_gtm_admin_deactivate'), $this->pagehook, 'normal', 'core');
	}

	//executed to show the plugins complete admin page
	function on_show_page() {
		global $bp, $wpdb;
		global $screen_layout_columns;

		//define some data can be given to each metabox during rendering
		$bp_gtm = get_option( 'bp_gtm' );
		?>
		<div id="bp-gtm-admin-general" class="wrap">
		<?php screen_icon('options-general'); ?>
		<h2><?php _e( 'BP GTM System','bp_gtm') ?> <sup><?php echo 'v' . GTM_VERSION; ?></sup> &rarr; <?php _e( 'Group Tasks Management', 'bp_gtm' ) ?></h2>

		<?php
		if ( isset($_POST['saveData']) ) {
			$bp_gtm['deactivate'] = $_POST['bp_gtm_deactivate'];
         $bp_gtm['mce'] = $_POST['bp_gtm_mce'];
         if ($_POST['bp_gtm_allgroups']=='all'){
            $bp_gtm['groups'] = 'all';
         }else{
            $bp_gtm['groups'] = $_POST['bp_gtm_groups'];
         }
         update_option( 'bp_gtm', $bp_gtm );

			echo "<div id='message' class='updated fade'><p>" . __( 'All changes were saved. Go and check results!', 'bp_gtm' ) . "</p></div>";
		}
		?>

		<form action="<?php echo site_url() . '/wp-admin/admin.php?page=bp-gtm-admin' ?>" id="bp-gtm-form" method="post">
			<?php wp_nonce_field('bp-gtm-admin-general'); ?>
			<?php wp_nonce_field('closedpostboxes', 'closedpostboxesnonce', false ); ?>
			<?php wp_nonce_field('meta-box-order', 'meta-box-order-nonce', false ); ?>

			<div id="poststuff" class="metabox-holder<?php echo 2 == $screen_layout_columns ? ' has-right-sidebar' : ''; ?>">
            <div id="side-info-column" class="inner-sidebar">
					<?php do_meta_boxes($this->pagehook, 'side', $bp_gtm); ?>
				</div>
				<div id="post-body" class="has-sidebar">
					<div id="post-body-content" class="has-sidebar-content">
						<?php do_meta_boxes($this->pagehook, 'normal', $bp_gtm); ?>
						<p>
							<input type="submit" value="<?php _e( 'Save Changes', 'bp_gtm' ) ?>" class="button-primary" name="saveData"/>
						</p>
					</div>
				</div>
			</div>
		</form>
		</div>
	<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready( function($) {
			// close postboxes that should be closed
			$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
			// postboxes setup
			postboxes.add_postbox_toggles('<?php echo $this->pagehook; ?>');
		});
		//]]>
	</script>

		<?php
	}
   /*
    * Sidebar Blocks
    */
	function on_bp_gtm_admin_privacy($bp_gtm) {
      echo '<p>';
      print_var($bp_gtm);
      echo '</p>';
	}

   function on_bp_gtm_admin_deactivate($bp_gtm) {
      _e('<p>Please check here how you would like to uninstall BP GTM System:</p>','bp_gtm');
      echo '<p><input name="bp_gtm_deactivate" type="radio" value="total" '. ( 'total' == $bp_gtm['deactivate'] ? 'checked="checked" ' : '' ) .'/> '. __('Deactivate the plugin and delete all options and tables from the DB', 'bp_gtm') .'</p>
            <p><input name="bp_gtm_deactivate" type="radio" value="only" '. ( 'only' == $bp_gtm['deactivate'] ? 'checked="checked" ' : '' ) .'/> '. __('Deactivate the plugin only, all saved data won\'t be touched', 'bp_gtm') .'</p>';
      _e('<p>After choosing deactivation method you could go to <a href="plugins.php?plugin_status=all">Plugins\'s page</a> and deactivate the plugin safely.</p>','bp_gtm');
	}

   /*
    * Main Content Blocks
    */
	function on_bp_gtm_admin_main($bp_gtm) {
      _e('<p>Choose here groups you want to allow to have GTM System available (all of them are sorted alphabetically):</p>','bp_gtm');

      echo '<ul class="groups-list">';
      echo '<li><input type="checkbox" id="bp_gtm_allgroups" name="bp_gtm_allgroups" '.( 'all' == $bp_gtm['groups'] ? 'checked="checked" ' : '' ).'value="all" /> '.__('All groups', 'bp_gtm').'</li>';
      $arg['type'] = 'alphabetical';
      if ( bp_has_groups($arg) ) {
         while ( bp_groups() ) : bp_the_group();
            $description = preg_replace( array('<<p>>', '<</p>>'), '', bp_get_group_description_excerpt() );
            echo '<li><input name="bp_gtm_groups['.bp_get_group_id().']" class="bp_gtm_groups" type="checkbox" '.( ('all' == $bp_gtm['groups']) || ($bp_gtm['groups'][bp_get_group_id()] == 'on') ? 'checked="checked" ' : '' ).'value="on" /> <a href="'.bp_get_group_permalink().'" target="_blank">'. bp_get_group_name() .'</a> &rarr; '.$description.'</li>';
         endwhile;
      }
      echo '</ul>';
	}

	function on_bp_gtm_admin_mce($bp_gtm) {
      _e('Do you want to allow to use Rich Editor (TinyMCE) to format project/task description with html tags?','bp_gtm');
      echo '<p><input name="bp_gtm_mce" type="radio" value="on" '. ( 'on' == $bp_gtm['mce'] ? 'checked="checked" ' : '' ) .'/> '. __('Enable', 'bp_gtm') .'</p>
            <p><input name="bp_gtm_mce" type="radio" value="off" '. ( 'off' == $bp_gtm['mce'] ? 'checked="checked" ' : '' ) .'/> '. __('Disable', 'bp_gtm') .'</p>';
   }

}
?>