<?php
/*
Plugin Name: BP GTM System
Plugin URI: http://ovirium.com/plugins/bp-gtm-system/
Description: Create a tasks management system for BP groups in your network.
Author: slaFFik
Version: 0.9.5
DB Version: 27
Author URI: http://cosydale.com/
Domain Path: /langs/
Text Domain: bp_gtm
*/

add_action('bp_init', 'bp_gtm_init');
function bp_gtm_init(){
   require ( dirname(__File__) . '/bp-gtm-core.php' );

   register_deactivation_hook( __File__, 'bp_gtm_deactivation' );
   $file_data = bp_gtm_get_file_data( GTM_DIR.'/bp-gtm.php', $default_headers);
   
   $bp_gtm['deactivate'] = 'total';
   $bp_gtm['mce'] = 'on';
   $bp_gtm['groups'] = 'all';
   $bp_gtm['db_version'] = '1';
	add_option('bp_gtm', $bp_gtm, '', 'yes');
}

/*
 * Register $bp->gtm Globals
 */
function bp_gtm_setup_globals() {
	global $bp, $wpdb;

	/* For internal identification */
	$bp->gtm->id = 'gtm';
   $bp->gtm->slug = 'gtm';

	$bp->gtm->table_tasks = $wpdb->base_prefix . 'bp_gtm_tasks';
   $bp->gtm->table_projects = $wpdb->base_prefix . 'bp_gtm_projects';
   $bp->gtm->table_discuss = $wpdb->base_prefix . 'bp_gtm_discuss';
   $bp->gtm->table_terms = $wpdb->base_prefix . 'bp_gtm_terms';
   $bp->gtm->table_taxon = $wpdb->base_prefix . 'bp_gtm_taxon';
   $bp->gtm->table_resps = $wpdb->base_prefix . 'bp_gtm_resps';

	$bp->gtm->format_notification_function = 'bp_gtm_format_notifications';

	/* Register this in the active components array */
	$bp->active_components[$bp->gtm->slug] = $bp->gtm->id;

//	if ( bp_is_active( 'forums' ) ) {}

	$bp->gtm->valid_status = apply_filters( 'bp_gtm_valid_status', array( 'public', 'private', 'hidden' ) );

	do_action( 'bp_gtm_setup_globals' );
}
add_action( 'bp_setup_globals', 'bp_gtm_setup_globals' );

/*
 * Install & Check DB tables
 */
function bp_gtm_check_installed() {
	/* Need to check db tables exist */
   $bp_gtm = get_option( 'bp_gtm' );
	if ( $bp_gtm['db_version'] < GTM_DB_VERSION )
		bp_gtm_install();
}
add_action( 'admin_menu', 'bp_gtm_check_installed' );

function bp_gtm_install() {
	global $wpdb, $bp;
   $bp_gtm = get_option('bp_gtm');

	if ( !empty($wpdb->charset) )
		$charset_collate = "DEFAULT CHARACTER SET {$wpdb->charset}";

	$sql[] = "CREATE TABLE {$bp->gtm->table_tasks} (
	  		`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
         `name` varchar(200) NOT NULL,
         `desc` longtext NOT NULL,
			`status` varchar(10) NOT NULL DEFAULT 'public',
         `parent_id` bigint(20) NOT NULL DEFAULT '0',
			`creator_id` bigint(20) NOT NULL,
         `group_id` bigint(20),
         `project_id` bigint(20) NOT NULL,
	  		`resp_id` varchar(500) NOT NULL,
			`date_created` datetime NOT NULL,
         `deadline` datetime NOT NULL,
         `done` tinyint(1) NOT NULL DEFAULT '0',
         `discuss_count` NOT NULL DEFAULT '0',
         KEY `parent_id` (parent_id),
		   KEY `creator_id` (creator_id),
         KEY `resp_id` (resp_id),
		   KEY `status` (status)
	 	   ) {$charset_collate};";

	$sql[] = "CREATE TABLE {$bp->gtm->table_discuss} (
	  		`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
         `text` longtext NOT NULL,
         `author_id` bigint(20) NOT NULL,
         `task_id` bigint(20) NOT NULL DEFAULT '0',
         `project_id` bigint(20) NOT NULL DEFAULT '0',
         `group_id` bigint(20) NOT NULL  DEFAULT '0',
			`date_created` datetime NOT NULL,
		   KEY `author_id` (author_id),
         KEY `task_id` (task_id),
		   KEY `project_id` (project_id)
	 	   ) {$charset_collate};";

	$sql[] = "CREATE TABLE {$bp->gtm->table_projects} (
	  		`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
         `name` varchar(200) NOT NULL,
         `desc` longtext NOT NULL,
         `status` varchar(10) NOT NULL DEFAULT 'public',
			`group_id` bigint(20),
         `creator_id` bigint(20) NOT NULL,
	  		`resp_id` varchar(500) NOT NULL,
			`date_created` datetime NOT NULL,
         `deadline` datetime NOT NULL,
         `done` tinyint(1) NOT NULL DEFAULT '0',
         `discuss_count` NOT NULL DEFAULT '0',
		   KEY `creator_id` (creator_id),
         KEY `resp_id` (resp_id),
		   KEY `status` (status)
	 	   ) {$charset_collate};";
         
	$sql[] = "CREATE TABLE {$bp->gtm->table_terms} (
	  		`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
         `taxon` varchar(20) NOT NULL,
         `group_id` bigint(20),
         `name` varchar(100) NOT NULL
	 	   ) {$charset_collate};";
	$sql[] = "CREATE TABLE {$bp->gtm->table_taxon} (
	  		`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
			`task_id` bigint(20) NOT NULL DEFAULT '0',
	  		`project_id` bigint(20),
         `group_id` bigint(20),
         `term_id` bigint(20) NOT NULL,
         `taxon` varchar(20) NOT NULL,
		   KEY `task_id` (task_id),
         KEY `project_id` (project_id)
	 	   ) {$charset_collate};";

	$sql[] = "CREATE TABLE {$bp->gtm->table_resps} (
			`task_id` bigint(20) NOT NULL DEFAULT '0',
	  		`project_id` bigint(20) NOT NULL DEFAULT '0',
         `group_id` bigint(20) NOT NULL DEFAULT '0',
         `resp_id` bigint(20) NOT NULL,
		   KEY `resp_id` (resp_id)
	 	   ) {$charset_collate};";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);

	do_action( 'bp_gtm_install' );

   $bp_gtm['db_version'] = GTM_DB_VERSION;
	update_option('bp_gtm', $bp_gtm);
}

/*
 * Deactivation hook
 */
function bp_gtm_deactivation() {
   global $wpdb, $bp;
   $bp_gtm = get_option('bp_gtm');
   if ( $bp_gtm['deactivate'] == 'total' ) {
      $wpdb->query( "DROP TABLE {$bp->gtm->table_tasks}" );
      $wpdb->query( "DROP TABLE {$bp->gtm->table_projects}" );
      $wpdb->query( "DROP TABLE {$bp->gtm->table_taxon}" );
      $wpdb->query( "DROP TABLE {$bp->gtm->table_terms}" );
      $wpdb->query( "DROP TABLE {$bp->gtm->table_discuss}" );
      $wpdb->query( "DROP TABLE {$bp->gtm->table_resps}" );
      delete_option('bp_gtm');
   }
}

/*
 * Different useful functions :)
 */
function print_var($var, $return = false) {
   if ($return == false) echo '<pre>';
   print_r ($var, $return);
   if ($return == false) echo '</pre><br>';
}

function print_globals(){
   global $bp, $wpdb;
   print_var($bp);
}
//add_action('wp_footer','print_globals');

function bp_gtm_get_file_data( $file, $default_headers ) {

   $default_headers = array(
		'Name' => 'Plugin Name',
		'PluginURI' => 'Plugin URI',
		'Version' => 'Version',
      'DBVersion' => 'DB Version',
		'Description' => 'Description',
		'Author' => 'Author',
		'AuthorURI' => 'Author URI',
	);

	$fp = fopen( $file, 'r' );
	$file_data = fread( $fp, 512 );
	fclose( $fp );

	foreach ( $default_headers as $field => $regex ) {
		preg_match( '/' . preg_quote( $regex, '/' ) . ':(.*)$/mi', $file_data, ${$field});
		if ( !empty( ${$field} ) )
			${$field} = _cleanup_header_comment( ${$field}[1] );
		else
			${$field} = '';
	}

	$file_data = compact( array_keys( $default_headers ) );

	return $file_data;
}
?>
